// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 1999, 2004 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************
package com.ibm.etools.marshall.util;

/**
 * This class defines the behavior for a range of string values.
 * The string are compared lexicographically to determine if they
 * fall within the upper and lower ranges.  This class is intended to
 * be used with the possible value construct on a field.
 */

public class StringRange implements IRangeObject
{
	private static String copyright = "(c) Copyright IBM Corporation 1999, 2004.";
	static final long serialVersionUID = 3348787800915702263L;

	protected String lowerRange_;
	protected String upperRange_;
/**
 * Creates a new empty instance of an StringRange object.
 */

public StringRange()
{
	lowerRange_ = new String();
	upperRange_ = new String();
}
/**
 * Creates a new instance of an StringRange object with the specified upper
 * and lower ranges.
 * @param lowerRange The lower range.
 * @param upperRange The upper range.
 * @exception java.lang.IllegalArgumentException The upper range is less than
 * the lower range, or either the lowerRange or upperRange is <code>null</code>.
 */

public StringRange(String lowerRange, String upperRange) throws IllegalArgumentException
{
	if ((lowerRange == null) || (upperRange == null))
		throw new IllegalArgumentException();

	if (upperRange.compareTo(lowerRange) < 0)
		throw new IllegalArgumentException(upperRange);

	lowerRange_ = lowerRange;
	upperRange_ = upperRange;
}
/**
 * Creates a new object of the same class as this object. It then initializes
 * each of the new object's fields by assigning it the same value as
 * the corresponding field in this object. No constructor is called.
 * @return A new object initialized to the same state as this object.
 */

public Object clone()
{
	try
	{
		StringRange newType = (StringRange)super.clone();

		return (newType);
	}
	catch (CloneNotSupportedException ex)
	{
		throw new java.lang.InternalError(ex.getMessage());
	}
}
/**
 * This method determines if the two string range objects are equivalent.
 * @return <code>true</code> if this range object is the same as the obj
 * argument; <code>false</code> otherwise.
 * @param obj The reference object with which to compare.
 */

public boolean equals (Object obj)
{
	if (obj == null)
		return (false);

	if (this == obj)
		return (true);

	if (!(obj instanceof StringRange))
		return (false);

	StringRange tmpRange = (StringRange)obj;

	if (!(lowerRange_.equals(tmpRange.lowerRange_)))
		return (false);

	if (!(upperRange_.equals(tmpRange.upperRange_)))
		return (false);

	return (true);
}
/**
 * Returns the lower range, or bounds, of the range object as a
 * java.lang.String object.
 * @return The lower range, or bounds, of the range object.
 */

public Object getLowerRange()
{
	return (lowerRange_);
}
/**
 * Returns all of the values of the range in a String array  Each value
 * int the array is a java.lang.String object.
 * @return All of the values of the range in an object array.
 */

public Object[] getRangeValues()
{
	String[] values = new String[2];

	values[0] = lowerRange_;
	values[1] = upperRange_;

	return (values);
}
/**
 * Returns the upper range, or bounds, of the range object as a
 * java.lang.String object.
 * @return The upper range, or bounds, of the range object.
 */

public Object getUpperRange()
{
	return (upperRange_);
}
/**
 * Tests whether the specified value lies within the upper and lower range
 * set on the range object.
 * @return <code>true</code> if the specified value lies within the upper
 * and lower range; <code>false</code> otherwise.
 * @param value The value to compare against.  Must be a java.lang.String object.
 */

public boolean isInRange (Object value)
{
	if (!(value instanceof String))
		return (false);

	String stringVal = (String)value;

	return (isInRange (lowerRange_, upperRange_, stringVal));
}
/**
 * Tests whether the specified value lies within the specifed upper and lower
 * range.
 * @return <code>true</code> if the specified value lies within the upper
 * and lower range; <code>false</code> otherwise.
 * @param lowerRange The lower range limit.
 * @param upperRange The upper range limit.
 * @param value The value to compare against.
 * @exception java.lang.IllegalArgumentException The upper range is less than
 * the lower range, or either the lowerRange, upperRange, or value is <code>null</code>.
 */

public static boolean isInRange (String lowerRange, String upperRange, String value)
	throws IllegalArgumentException
{
	if ((lowerRange == null) || (upperRange == null) || (value == null))
		throw new IllegalArgumentException();

	if (upperRange.compareTo(lowerRange) < 0)
		throw new IllegalArgumentException(upperRange);

	if ((lowerRange.compareTo (value) <= 0) &&
			(upperRange.compareTo (value) >=0))
		return (true);

	return (false);
}
/**
 * Sets the lower range, or bounds, of the range object.
 * @param value The lower range value.    Must be a java.lang.String object.
 * @exception IllegalArgumentException The value specified is not valid for
 * this range object, or is <code>null</code>.
 */

public void setLowerRange (Object value) throws IllegalArgumentException
{
	if (!(value instanceof String))
		throw new IllegalArgumentException(value.toString());

	lowerRange_ = (String)value;

	return;
}
/**
 * Sets the upper range, or bounds, of the range object.
 * @param value The upper range value.  Must be a java.lang.String object.
 * @exception IllegalArgumentException The value specified is not valid for
 * this range object, or is <code>null</code>.
 */

public void setUpperRange (Object value) throws IllegalArgumentException
{
	if (!(value instanceof String))
		throw new IllegalArgumentException(value.toString());

	upperRange_ = (String)value;

	return;
}
}
